<?php
/**
 * Restriçoes para lancar os Efetivos.
 */
namespace Planejamento\Logic\Efetivos\Exception;

class RestricoesLancamentoEfetivos extends \Planejamento\Logic\Exception
{

    private $messageName;

    /**
     * Construtor.
     *
     * Recebe o nome da mensagem cadastrada no setforms.
     *
     * @param string $messageName
     * @param string $message
     * @param int $code
     * @param \Exception|null $previous
     */
    public function __construct($messageName, $code = 0, \Exception $previous = null)
    {
        parent::__construct($messageName, $code, $previous);
        $this->messageName = $messageName;
    }


    /**
     * Retorna o nome da mensagem cadastrada no Setforms para esta excecao.
     *
     * @return string
     */
    public function getMessageName()
    {
        return $this->messageName;
    }


    /**
     * Nao ha permissao para lancar efetivos com data do cardapio superior a data de processamento
     * @static
     * @throws RestricoesLancamentoEfetivos
     */
    public static function DataCardapioSuperiorDataProcessamento()
    {
        throw new self (tk_get_message_by_name("pla01000_dtcardapio_menor_igual_dtprocessamento"));
    }


    /**
     * Nao ha permissao para lancar efetivos sem retirada
     * @static
     * @throws RestricoesLancamentoEfetivos
     */
    public static function LancamentoSemRetirada()
    {
        throw new self (tk_get_message_by_name("pla01000_produto_baixado_estoque"));
    }


    /**
     * Obriga que um cardapio que possui retirada tenha um numero de efetivos superior a zero.
     * @static
     * @throws RestricoesLancamentoEfetivos
     */
    public static function CardapioComRetirada()
    {
        throw new self (tk_get_message_by_name("pla01000_valida_cardapio_com_retirada"));
    }


    /**
     * O intervalo entre a data do cardapio e a data de processamento da filial ultrapassa a tolerancia de dias
     * estabelecidos para lancamento dos efetivos
     * @static
     * @param integer $nrDiasAnterioresDtProc Num. dias anteriores a data de processamento
     * @throws RestricoesLancamentoEfetivos
     */
    public static function BloqueioDiasFechados($nrDiasAnterioresDtProc)
    {
        throw new self (tk_get_message_by_name("pla01000_bloqueia_efetivos_dias_fechados", array($nrDiasAnterioresDtProc)));
    }

}
